Meet Sam
========

|Doc badge| |Black badge| |Pypi badge|

.. |Doc badge| image:: https://readthedocs.org/projects/meetsam/badge/?version=latest
       :target: https://meetsam.readthedocs.io/en/latest/?badge=latest
       :alt: Documentation Status

.. |Black badge| image:: https://img.shields.io/badge/code%20style-black-000000.svg
   :target: https://github.com/psf/black
   :alt: Code Formatter

.. |Pypi badge| image:: https://badge.fury.io/py/meetSam.svg
       :target: https://badge.fury.io/py/meetSam
